"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.jsonParser = exports.rawBody = void 0;
const content_disposition_1 = require("content-disposition");
const content_type_1 = require("content-type");
const raw_body_1 = __importDefault(require("raw-body"));
const n8n_workflow_1 = require("n8n-workflow");
const config_1 = __importDefault(require("../config"));
const payloadSizeMax = config_1.default.getEnv('endpoints.payloadSizeMax');
const rawBody = async (req, res, next) => {
    var _a;
    if ('content-type' in req.headers) {
        const { type: contentType, parameters } = (() => {
            try {
                return (0, content_type_1.parse)(req);
            }
            catch {
                return { type: undefined, parameters: undefined };
            }
        })();
        req.contentType = contentType;
        req.encoding = ((_a = parameters === null || parameters === void 0 ? void 0 : parameters.charset) !== null && _a !== void 0 ? _a : 'utf-8').toLowerCase();
        const contentDispositionHeader = req.headers['content-disposition'];
        if (contentDispositionHeader === null || contentDispositionHeader === void 0 ? void 0 : contentDispositionHeader.length) {
            const { type, parameters: { filename }, } = (0, content_disposition_1.parse)(contentDispositionHeader);
            req.contentDisposition = { type, filename };
        }
    }
    req.readRawBody = async () => {
        if (!req.rawBody) {
            req.rawBody = await (0, raw_body_1.default)(req, {
                length: req.headers['content-length'],
                limit: `${String(payloadSizeMax)}mb`,
            });
            req._body = true;
        }
    };
    next();
};
exports.rawBody = rawBody;
const jsonParser = async (req, res, next) => {
    await req.readRawBody();
    if (Buffer.isBuffer(req.rawBody)) {
        if (req.contentType === 'application/json') {
            try {
                req.body = (0, n8n_workflow_1.jsonParse)(req.rawBody.toString(req.encoding));
            }
            catch (error) {
                res.status(400).send({ error: 'Failed to parse request body' });
                return;
            }
        }
        else {
            req.body = {};
        }
    }
    next();
};
exports.jsonParser = jsonParser;
//# sourceMappingURL=bodyParser.js.map